@@ -1,4 +1,4 @@
-"""<b>plotly\_resampler</b>: interactive visualiziations of large sequences of data
+"""<b>plotly\_resampler</b>: interactive visualizations of large sequences of data
 
 .. include:: ../docs/pdoc_include/root_documentation.md
 
@@ -10,7 +10,7 @@ from .downsamplers import LTTB, EveryNthPoint, AggregationDownsampler
 
 __docformat__ = "numpy"
 __author__ = "Jonas Van Der Donckt, Jeroen Van Der Donckt, Emiel Deprost"
-__version__ = "0.2.4"
+__version__ = "0.2.5"
 
 __pdoc__ = {}
 
